# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.

# pyre-unsafe

# This source code is licensed under the license found in the
# LICENSE file in the root directory of this source tree.

from typing import Optional

def get_gpu_node_id(cache_file_path: Optional[str]) -> str: ...
